#!/usr/bin/env python

import sys
import os
from mpi4py import MPI
from netCDF4 import Dataset
from nes.nc_projections.default_nes import Nes
from nes.nc_projections.rotated_nes import RotatedNes
from nes.nc_projections.latlon_nes import LatLonNes


def open_netcdf(path, comm=None, xarray=False, info=False):
    if comm is None:
        comm = MPI.COMM_WORLD
    else:
        comm = comm

    if xarray:
        dataset = None
    else:
        if comm.Get_size() == 1:
            dataset = Dataset(path, format="NETCDF4", mode='r', parallel=False)
        else:
            dataset = Dataset(path, format="NETCDF4", mode='r', parallel=True, comm=comm, info=MPI.Info())

    # Rotated
    if is_rotated(dataset):
        nessy = RotatedNes(comm=comm, dataset=dataset, xarray=xarray, info=info)
    else:
        nessy = LatLonNes(comm=comm, dataset=dataset, xarray=xarray, info=info)

    return nessy


def is_rotated(dataset):
    if 'rotated_pole' in dataset.variables.keys():
        return True
    else:
        return False


