#!/usr/bin/env python

from nes.nc_projections.default_nes import Nes


class LatLonNes(Nes):
    def __init__(self, comm=None, path=None, info=False, dataset=None, xarray=False):
        """
        Initialize the goddess class
        """
        super(LatLonNes, self).__init__(comm=comm, path=path, info=info, dataset=dataset, xarray=xarray)

        self.var_dim = ('lat', 'lon')
        self.lat_dim = ('lat',)
        self.lon_dim = ('lon',)

    def create_dimensions(self, netcdf):
        """
        Create the 'rlat', 'rlon' dimensions and the super dimensions ('lev', 'time').

        :param netcdf: NetCDF object.
        :type netcdf: Dataset

        :return: True when the writing is finished.
        :rtype: bool
        """
        super(LatLonNes, self).create_dimensions(netcdf)

        netcdf.createDimension('lon', len(self._lon['data']))
        netcdf.createDimension('lat', len(self._lat['data']))

        return None

    @staticmethod
    def set_var_crs(var):
        """
        Set the grid_mapping to 'rotated_pole'.

        :param var: netCDF var object.
        :type var: Variable

        :return: True when the writing is finished.
        :rtype: bool
        """
        var.grid_mapping = 'crs'

        return None

    def set_crs(self, netcdf):
        """
        Create the 'crs' variable for the rotated latitude longitude grid_mapping.

        :param netcdf: NetCDF object.
        :type netcdf: Dataset

        :return: True when the writing is finished.
        :rtype: bool
        """

        mapping = netcdf.createVariable('crs', 'c')
        # mapping = netcdf.createVariable('crs', 'i')
        mapping.grid_mapping_name = "latitude_longitude"
        mapping.semi_major_axis = 6371000.0
        mapping.inverse_flattening = 0

        return None
